==> icons-vue-0.6.0.tgz: package/lib/data--check/16.js <==
'use strict';

var _rollupPluginBabelHelpers = require('../_rollupPluginBabelHelpers-00d81fcb.js');
var iconHelpers = require('@rocketsoftware/icon-helpers');

var virtual_DataCheck16 = {
  name: 'DataCheck16',
  functional: true,
  // We use title as the prop name as it is not a valid attribute for an SVG
  // HTML element
  props: ['title'],
  render: function render(createElement, context) {
    var children = context.children,
        data = context.data,
        listeners = context.listeners,
        props = context.props;
    var attrs = iconHelpers.getAttributes(_rollupPluginBabelHelpers._objectSpread2({
      width: '16',
      height: '16',
      viewBox: '0 0 32 32',
      preserveAspectRatio: 'xMidYMid meet',
      xmlns: 'http://www.w3.org/2000/svg',
      // Special case here, we need to coordinate that we are using title,
      // potentially, to get the right focus attributes
      title: props.title
    }, data.attrs));
    var svgData = {
      attrs: attrs,
      on: listeners
    };

    if (data.staticClass) {
      svgData.class = _rollupPluginBabelHelpers._defineProperty({}, data.staticClass, true);
    }

    if (data.class) {
      svgData.class = svgData.class || {}; // may be no static class

      svgData.class[data.class] = true;
    } // remove style set by getAttributes


    delete svgData.attrs.style; // combine incoming staticStyle, style with default willChange

    svgData.style = _rollupPluginBabelHelpers._objectSpread2({
      willChange: 'transform'
    }, data.staticStyle, {}, data.style);
    return createElement('svg', svgData, [props.title && createElement('title', null, props.title), createElement('polygon', {
      attrs: {
        "points": "23 27.18 20.41 24.59 19 26 23 30 30 23 28.59 21.59 23 27.18"
      }
    }), createElement('circle', {
      attrs: {
        "cx": "11",
        "cy": "8",
        "r": "1"
      }
    }), createElement('circle', {
      attrs: {
        "cx": "11",
        "cy": "16",
        "r": "1"
      }
    }), createElement('circle', {
      attrs: {
        "cx": "11",
        "cy": "24",
        "r": "1"
      }
    }), createElement('path', {
      attrs: {
        "d": "M24,3H8A2,2,0,0,0,6,5V27a2,2,0,0,0,2,2h8V27H8V21H26V5A2,2,0,0,0,24,3Zm0,16H8V13H24Zm0-8H8V5H24Z"
      }
    }), children]);
  }
};

module.exports = virtual_DataCheck16;

==> icons-vue-10.6.1.tgz: package/lib/data--check/16.js <==
'use strict';

var __chunk_1 = require('../chunk-d2faeea1.js');
var iconHelpers = require('@carbon/icon-helpers');

var virtual_DataCheck16 = {
  name: 'DataCheck16',
  functional: true,
  // We use title as the prop name as it is not a valid attribute for an SVG
  // HTML element
  props: ['title'],
  render: function render(createElement, context) {
    var children = context.children,
        data = context.data,
        listeners = context.listeners,
        props = context.props;
    var attrs = iconHelpers.getAttributes(__chunk_1._objectSpread2({
      width: '16',
      height: '16',
      viewBox: '0 0 32 32',
      preserveAspectRatio: 'xMidYMid meet',
      xmlns: 'http://www.w3.org/2000/svg',
      // Special case here, we need to coordinate that we are using title,
      // potentially, to get the right focus attributes
      title: props.title
    }, data.attrs));
    var svgData = {
      attrs: attrs,
      on: listeners
    };

    if (data.staticClass) {
      svgData.class = __chunk_1._defineProperty({}, data.staticClass, true);
    }

    if (data.class) {
      svgData.class[data.class] = true;
    }

    return createElement('svg', svgData, [props.title && createElement('title', null, props.title), createElement('path', {
      attrs: {
        "d": "M23 27.18l-2.59-2.59L19 26l4 4 7-7-1.41-1.41L23 27.18z"
      }
    }), createElement('circle', {
      attrs: {
        "cx": "11",
        "cy": "8",
        "r": "1"
      }
    }), createElement('circle', {
      attrs: {
        "cx": "11",
        "cy": "16",
        "r": "1"
      }
    }), createElement('circle', {
      attrs: {
        "cx": "11",
        "cy": "24",
        "r": "1"
      }
    }), createElement('path', {
      attrs: {
        "d": "M24 3H8a2 2 0 0 0-2 2v22a2 2 0 0 0 2 2h8v-2H8v-6h18V5a2 2 0 0 0-2-2zm0 16H8v-6h16zm0-8H8V5h16z"
      }
    }), children]);
  }
};

module.exports = virtual_DataCheck16;
